pub enum ErrorVisibility {
User,
Internal,
}Expand description
Whether an error should be surfaced directly to a human.
Variants
User
Safe and useful to show directly to the caller.
Internal
Primarily diagnostic for runtime internals.