QueuePressureBoundaryKind

Enum QueuePressureBoundaryKind 

pub enum QueuePressureBoundaryKind {
    ReceiveAttempted,
    ReceiveReady,
    ReceiveEmpty,
    ReceiveClosed,
    ReserveAttempted,
    ReserveReady,
    ReserveFull,
    SendCommitted,
    SendDropped,
}
Where queue pressure was observed at the port boundary.

Variants



ReceiveAttempted

A receive operation is about to inspect or wait on an input queue.



ReceiveReady

A receive operation dequeued a packet.



ReceiveEmpty

A receive operation found no currently available packet.



ReceiveClosed

A receive operation observed upstream closure.



ReserveAttempted

An output reserve operation is about to inspect or wait on capacity.



ReserveReady

An output reserve operation acquired capacity.



ReserveFull

An output reserve operation found all connected capacity full.



SendCommitted

A reserved output packet committed to the output boundary.



SendDropped

A committed output packet had no downstream edge and was dropped.