ErrorMetadataRecord

Struct ErrorMetadataRecord 

pub struct ErrorMetadataRecord { /* private fields */ }
One structured error observation at a runtime boundary.

Implementations

Source

impl ErrorMetadataRecord

pub fn node_failed(context: &NodeContext, error: PureflowError) -> Self

Create a node failure observation.

pub const fn workflow_failed( workflow_id: WorkflowId, execution: ExecutionMetadata, error: PureflowError, ) -> Self

Create a workflow failure observation.

pub const fn workflow_failed_with_diagnostic( workflow_id: WorkflowId, execution: ExecutionMetadata, error: PureflowError, diagnostic: ErrorDiagnosticMetadata, ) -> Self

Create a workflow failure observation with structured diagnostic data.

pub const fn kind(&self) -> ErrorMetadataKind

Error observation scope.

pub const fn workflow_id(&self) -> &WorkflowId

Workflow associated with this error.

pub const fn node_id(&self) -> Option<&NodeId>

Node associated with this error, when the error came from a node.

pub const fn execution(&self) -> &ExecutionMetadata

Execution attempt associated with this error.

pub const fn error(&self) -> &PureflowError

Structured Pureflow error observed.

pub const fn diagnostic(&self) -> Option<&ErrorDiagnosticMetadata>

Structured diagnostic payload associated with this error, when present.