pub struct ExternalEffectMetadataRecord { /* private fields */ }Expand description
One structured external effect observation at a node boundary.
Implementations
Sourceimpl ExternalEffectMetadataRecord
impl ExternalEffectMetadataRecord
Sourcepub fn new(
kind: ExternalEffectMetadataKind,
context: NodeContext,
effect: EffectCapability,
operation: impl Into<String>,
target: impl Into<String>,
response_status: Option<String>,
) -> Self
pub fn new( kind: ExternalEffectMetadataKind, context: NodeContext, effect: EffectCapability, operation: impl Into<String>, target: impl Into<String>, response_status: Option<String>, ) -> Self
Create an external effect observation.
Sourcepub fn requested(
context: NodeContext,
effect: EffectCapability,
operation: impl Into<String>,
target: impl Into<String>,
) -> Self
pub fn requested( context: NodeContext, effect: EffectCapability, operation: impl Into<String>, target: impl Into<String>, ) -> Self
Create an external effect request observation.
Sourcepub fn completed(
context: NodeContext,
effect: EffectCapability,
operation: impl Into<String>,
target: impl Into<String>,
response_status: impl Into<String>,
) -> Self
pub fn completed( context: NodeContext, effect: EffectCapability, operation: impl Into<String>, target: impl Into<String>, response_status: impl Into<String>, ) -> Self
Create a completed external effect observation.
Sourcepub fn failed(
context: NodeContext,
effect: EffectCapability,
operation: impl Into<String>,
target: impl Into<String>,
response_status: Option<String>,
) -> Self
pub fn failed( context: NodeContext, effect: EffectCapability, operation: impl Into<String>, target: impl Into<String>, response_status: Option<String>, ) -> Self
Create a failed external effect observation.
Sourcepub const fn kind(&self) -> ExternalEffectMetadataKind
pub const fn kind(&self) -> ExternalEffectMetadataKind
External effect observation kind.
Sourcepub const fn context(&self) -> &NodeContext
pub const fn context(&self) -> &NodeContext
Runtime context for the node that observed the external effect.
Sourcepub const fn effect(&self) -> EffectCapability
pub const fn effect(&self) -> EffectCapability
Declared effect capability associated with this observation.
Sourcepub fn response_status(&self) -> Option<&str>
pub fn response_status(&self) -> Option<&str>
Stable response status associated with this observation, when known.