pub struct InputPortHandle { /* private fields */ }Expand description
Channel-backed input endpoint for one declared input port.
Implementations
Sourceimpl InputPortHandle
impl InputPortHandle
Sourcepub const fn disconnected(port_id: PortId) -> Self
pub const fn disconnected(port_id: PortId) -> Self
Create an input handle with no connected upstream edge.
Sourcepub const fn connected_edge_count(&self) -> usize
pub const fn connected_edge_count(&self) -> usize
Number of upstream bounded edges connected to this input port.