pub struct OutputPortHandle { /* private fields */ }Expand description
Channel-backed output endpoint for one declared output port.
Implementations
Sourceimpl OutputPortHandle
impl OutputPortHandle
Sourcepub const fn disconnected(port_id: PortId) -> Self
pub const fn disconnected(port_id: PortId) -> Self
Create an output handle with no connected downstream edge.
Sourcepub const fn connected_edge_count(&self) -> usize
pub const fn connected_edge_count(&self) -> usize
Number of downstream bounded edges connected to this output port.