Core traits and contracts for Pureflow.
Re-exports
pub use batch::BatchExecutor;pub use batch::BatchInputs;pub use batch::BatchOutputs;pub use batch::WasmModule;pub use context::CancellationHandle;pub use context::CancellationToken;pub use error::CancellationError;pub use error::PureflowError;pub use error::ErrorCode;pub use error::ErrorVisibility;pub use error::ExecutionError;pub use error::LifecycleError;pub use error::MetadataError;pub use error::RetryDisposition;pub use error::ValidationError;pub use message::PacketPayload;pub use metadata::DeadlockDiagnosticMetadata;pub use metadata::ErrorDiagnosticMetadata;pub use metadata::ErrorMetadataKind;pub use metadata::ErrorMetadataRecord;pub use metadata::ExternalEffectMetadataKind;pub use metadata::ExternalEffectMetadataRecord;pub use metadata::JsonlMetadataSink;pub use metadata::MessageBoundaryKind;pub use metadata::MessageBoundaryRecord;pub use metadata::MetadataRecord;pub use metadata::MetadataSink;pub use metadata::MetadataTier;pub use metadata::NoopMetadataSink;pub use metadata::TieredMetadataPolicy;pub use metadata::TieredMetadataSink;pub use metadata::metadata_record_to_json_value;pub use ports::InputPortHandle;pub use ports::OutputPacketValidator;pub use ports::OutputPortHandle;pub use ports::PortPacket;pub use ports::PortRecvError;pub use ports::PortSendError;pub use ports::PortSendPermit;pub use ports::PortsIn;pub use ports::PortsOut;pub use ports::bounded_edge_channel;
Modules
- batch
- Runtime-neutral batch execution boundary for host-owned adapters.
- capability
- Capability descriptors that constrain runtime behavior without owning graph shape.
- context
- Execution context and cancellation boundary types.
- error
- Shared error types for Pureflow runtime-facing APIs.
- lifecycle
- Lifecycle events and observer hooks at the runtime boundary.
- message
- Message envelope and routing metadata types.
- metadata
- Runtime metadata collection boundary.
- ports
- Pureflow-owned port handles for the executor boundary.
Traits
- Node
Executor - Async node interface for the first runtime skeleton.
Type Aliases
- Result
- Shared result type for runtime-facing APIs.