pub struct CancellationHandle { /* private fields */ }Expand description
Runtime-owned handle that can request cancellation for shared contexts.
Implementations
Sourceimpl CancellationHandle
impl CancellationHandle
Sourcepub fn token(&self) -> CancellationToken
pub fn token(&self) -> CancellationToken
Return a read-only token suitable for attaching to a NodeContext.
Sourcepub fn cancel(&self, request: CancellationRequest) -> bool
pub fn cancel(&self, request: CancellationRequest) -> bool
Request cancellation for every context sharing this handle’s token.
Returns true when this call recorded the first cancellation request.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Return whether cancellation has been requested.
Sourcepub fn request(&self) -> Option<CancellationRequest>
pub fn request(&self) -> Option<CancellationRequest>
Return the current cancellation request, if any.