pub struct NodeContext { /* private fields */ }Expand description
Minimal execution context passed to runtime-managed nodes.
Implementations
Sourceimpl NodeContext
impl NodeContext
Sourcepub fn new(
workflow_id: WorkflowId,
node_id: NodeId,
execution: ExecutionMetadata,
) -> Self
pub fn new( workflow_id: WorkflowId, node_id: NodeId, execution: ExecutionMetadata, ) -> Self
Create an active node context for one execution attempt.
Sourcepub fn with_cancellation(self, request: CancellationRequest) -> Self
pub fn with_cancellation(self, request: CancellationRequest) -> Self
Create a copy of this context with cancellation requested.
Sourcepub fn with_cancellation_token(self, token: CancellationToken) -> Self
pub fn with_cancellation_token(self, token: CancellationToken) -> Self
Attach a shared cancellation token to this context.
Sourcepub const fn workflow_id(&self) -> &WorkflowId
pub const fn workflow_id(&self) -> &WorkflowId
Workflow currently being executed.
Sourcepub const fn execution(&self) -> &ExecutionMetadata
pub const fn execution(&self) -> &ExecutionMetadata
Execution metadata shared by nodes in the same run.
Sourcepub fn cancellation(&self) -> CancellationState
pub fn cancellation(&self) -> CancellationState
Cancellation state visible to this node.
Sourcepub fn cancellation_token(&self) -> CancellationToken
pub fn cancellation_token(&self) -> CancellationToken
Shared cancellation token visible to this node.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Return whether cancellation has been requested.