pub struct ErrorMetadataRecord { /* private fields */ }Expand description
One structured error observation at a runtime boundary.
Implementations
Sourceimpl ErrorMetadataRecord
impl ErrorMetadataRecord
Sourcepub fn node_failed(context: &NodeContext, error: PureflowError) -> Self
pub fn node_failed(context: &NodeContext, error: PureflowError) -> Self
Create a node failure observation.
Sourcepub const fn workflow_failed(
workflow_id: WorkflowId,
execution: ExecutionMetadata,
error: PureflowError,
) -> Self
pub const fn workflow_failed( workflow_id: WorkflowId, execution: ExecutionMetadata, error: PureflowError, ) -> Self
Create a workflow failure observation.
Sourcepub const fn workflow_failed_with_diagnostic(
workflow_id: WorkflowId,
execution: ExecutionMetadata,
error: PureflowError,
diagnostic: ErrorDiagnosticMetadata,
) -> Self
pub const fn workflow_failed_with_diagnostic( workflow_id: WorkflowId, execution: ExecutionMetadata, error: PureflowError, diagnostic: ErrorDiagnosticMetadata, ) -> Self
Create a workflow failure observation with structured diagnostic data.
Sourcepub const fn kind(&self) -> ErrorMetadataKind
pub const fn kind(&self) -> ErrorMetadataKind
Error observation scope.
Sourcepub const fn workflow_id(&self) -> &WorkflowId
pub const fn workflow_id(&self) -> &WorkflowId
Workflow associated with this error.
Sourcepub const fn node_id(&self) -> Option<&NodeId>
pub const fn node_id(&self) -> Option<&NodeId>
Node associated with this error, when the error came from a node.
Sourcepub const fn execution(&self) -> &ExecutionMetadata
pub const fn execution(&self) -> &ExecutionMetadata
Execution attempt associated with this error.
Sourcepub const fn error(&self) -> &PureflowError
pub const fn error(&self) -> &PureflowError
Structured Pureflow error observed.
Sourcepub const fn diagnostic(&self) -> Option<&ErrorDiagnosticMetadata>
pub const fn diagnostic(&self) -> Option<&ErrorDiagnosticMetadata>
Structured diagnostic payload associated with this error, when present.