pub struct QueuePressureRecord { /* private fields */ }Expand description
One queue pressure or capacity observation at a port boundary.
Implementations
Sourceimpl QueuePressureRecord
impl QueuePressureRecord
Sourcepub const fn new(
context: Option<NodeContext>,
direction: QueuePortDirection,
port_id: PortId,
kind: QueuePressureBoundaryKind,
connected_edge_count: usize,
capacity: Option<usize>,
queued_count: Option<usize>,
) -> Self
pub const fn new( context: Option<NodeContext>, direction: QueuePortDirection, port_id: PortId, kind: QueuePressureBoundaryKind, connected_edge_count: usize, capacity: Option<usize>, queued_count: Option<usize>, ) -> Self
Create a queue pressure observation.
Sourcepub const fn context(&self) -> Option<&NodeContext>
pub const fn context(&self) -> Option<&NodeContext>
Runtime context for the node that observed queue pressure, when known.
Sourcepub const fn direction(&self) -> QueuePortDirection
pub const fn direction(&self) -> QueuePortDirection
Direction of the observed port.
Sourcepub const fn kind(&self) -> QueuePressureBoundaryKind
pub const fn kind(&self) -> QueuePressureBoundaryKind
Boundary kind observed.
Sourcepub const fn connected_edge_count(&self) -> usize
pub const fn connected_edge_count(&self) -> usize
Number of connected graph edges behind this declared port.
Sourcepub const fn capacity(&self) -> Option<usize>
pub const fn capacity(&self) -> Option<usize>
Total known bounded capacity across connected edges, when connected.
Sourcepub const fn queued_count(&self) -> Option<usize>
pub const fn queued_count(&self) -> Option<usize>
Total currently queued packets across connected input edges, when observable.